package com.qmth.ops.api.controller.admin;

import com.qmth.ops.api.constants.OpsApiConstants;
import com.qmth.ops.api.security.AdminSession;
import com.qmth.ops.api.security.Permission;
import com.qmth.ops.api.vo.DocSupplierVO;
import com.qmth.ops.biz.domain.DocSupplier;
import com.qmth.ops.biz.service.DocClientService;
import com.qmth.ops.biz.service.DocSupplierService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;
import java.util.stream.Collectors;

@RestController
@RequestMapping(OpsApiConstants.ADMIN_URI_PREFIX + "/doc/supplier")
public class DocSupplierController {

    @Resource
    private DocSupplierService docSupplierService;

    @Resource
    private DocClientService docClientService;

    @PostMapping("/list")
    public List<DocSupplierVO> list() {
        return docSupplierService.list().stream().map(DocSupplierVO::new).collect(Collectors.toList());
    }

    @PostMapping("/detail")
    public DocSupplier detail(@RequestParam Long id) {
        return docSupplierService.getById(id);
    }

    @PostMapping("/insert")
    public DocSupplier insert(@RequestAttribute AdminSession adminSession, DocSupplier supplier) {
        adminSession.hasPermission(Permission.DOC_SUPPLIER_INSERT);
        docSupplierService.insert(supplier);
        docClientService.init();
        return docSupplierService.getById(supplier.getId());
    }

    @PostMapping("/update")
    public DocSupplier update(@RequestAttribute AdminSession adminSession, DocSupplier supplier) {
        adminSession.hasPermission(Permission.DOC_SUPPLIER_EDIT);
        docSupplierService.update(supplier);
        docClientService.init();
        return docSupplierService.getById(supplier.getId());
    }

}
